aboutsummaryrefslogtreecommitdiff
path: root/gcc/config
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/config')
-rw-r--r--gcc/config/alpha/alpha.c22
-rw-r--r--gcc/config/alpha/alpha.h12
-rw-r--r--gcc/config/alpha/alpha.md2
-rw-r--r--gcc/config/alpha/elf.h14
-rw-r--r--gcc/config/alpha/linux.h9
-rw-r--r--gcc/config/alpha/vms.h33
-rw-r--r--gcc/config/alpha/xm-alpha.h8
-rw-r--r--gcc/config/arc/arc.c8
-rw-r--r--gcc/config/arm/arm.c20
-rw-r--r--gcc/config/i386/cygwin32.h3
-rw-r--r--gcc/config/i386/i386.c7
-rw-r--r--gcc/config/i386/i386.h2
-rw-r--r--gcc/config/i386/rtems.h2
-rw-r--r--gcc/config/i386/sco5.h6
-rw-r--r--gcc/config/i386/xm-dos.h3
-rw-r--r--gcc/config/i386/xm-mingw32.h13
-rw-r--r--gcc/config/i960/rtems.h2
-rw-r--r--gcc/config/linux.h19
-rw-r--r--gcc/config/m68k/linux.h7
-rw-r--r--gcc/config/m68k/m68k.c4
-rw-r--r--gcc/config/m68k/m68k.h6
-rw-r--r--gcc/config/m68k/rtems.h2
-rw-r--r--gcc/config/m68k/xm-mot3300.h9
-rw-r--r--gcc/config/m88k/dgux.h6
-rw-r--r--gcc/config/m88k/m88k.c6
-rw-r--r--gcc/config/m88k/xm-m88k.h13
-rw-r--r--gcc/config/mips/iris6.h4
-rw-r--r--gcc/config/mips/mips.c2
-rw-r--r--gcc/config/mips/mips.h2
-rw-r--r--gcc/config/mips/mips.md2
-rw-r--r--gcc/config/mips/rtems64.h2
-rw-r--r--gcc/config/mips/xm-mips.h4
-rw-r--r--gcc/config/mn10200/mn10200.c2
-rw-r--r--gcc/config/mn10200/mn10200.h5
-rw-r--r--gcc/config/mn10200/mn10200.md4
-rw-r--r--gcc/config/mn10300/mn10300.c2
-rw-r--r--gcc/config/mn10300/mn10300.h5
-rw-r--r--gcc/config/mn10300/mn10300.md6
-rw-r--r--gcc/config/pa/pa-hpux10.h4
-rw-r--r--gcc/config/pa/pa.c17
-rw-r--r--gcc/config/pa/pa.h6
-rw-r--r--gcc/config/pa/pa.md4
-rw-r--r--gcc/config/rs6000/linux.h2
-rw-r--r--gcc/config/rs6000/rs6000.c8
-rw-r--r--gcc/config/rs6000/rs6000.h10
-rw-r--r--gcc/config/rs6000/rs6000.md2
-rw-r--r--gcc/config/rs6000/rtems.h2
-rw-r--r--gcc/config/rs6000/sysv4.h10
-rw-r--r--gcc/config/rs6000/xm-cygwin32.h2
-rw-r--r--gcc/config/sh/rtems.h2
-rw-r--r--gcc/config/sh/sh.c26
-rw-r--r--gcc/config/sh/sh.h2
-rw-r--r--gcc/config/sh/sh.md16
-rw-r--r--gcc/config/sparc/linux-aout.h13
-rw-r--r--gcc/config/sparc/linux.h25
-rw-r--r--gcc/config/sparc/linux64.h21
-rw-r--r--gcc/config/sparc/rtems.h2
-rw-r--r--gcc/config/sparc/sparc.c9
-rw-r--r--gcc/config/sparc/sparc.h6
-rw-r--r--gcc/config/sparc/xm-linux.h2
-rw-r--r--gcc/config/v850/lib1funcs.asm2
-rw-r--r--gcc/config/v850/v850.c6
-rw-r--r--gcc/config/v850/v850.h11
-rw-r--r--gcc/config/v850/v850.md12
-rw-r--r--gcc/config/xm-linux.h16
-rw-r--r--gcc/config/xm-svr4.h10
66 files changed, 225 insertions, 301 deletions
diff --git a/gcc/config/alpha/alpha.c b/gcc/config/alpha/alpha.c
index 6155a1d..91c068c 100644
--- a/gcc/config/alpha/alpha.c
+++ b/gcc/config/alpha/alpha.c
@@ -1201,10 +1201,9 @@ alpha_adjust_cost (insn, link, dep_insn, cost)
if (alpha_cpu == PROCESSOR_EV5)
{
- /* On EV5, "A special bypass provides an effective latency of 0
- cycles for an ICMP or ILOG insn producing the test operand of an
- IBR or CMOV insn." */
-
+ /* And the lord DEC saith: "A special bypass provides an effective
+ latency of 0 cycles for an ICMP or ILOG insn producing the test
+ operand of an IBR or CMOV insn." */
if (recog_memoized (dep_insn) >= 0
&& (get_attr_type (dep_insn) == TYPE_ICMP
|| get_attr_type (dep_insn) == TYPE_ILOG)
@@ -1753,10 +1752,12 @@ alpha_builtin_saveregs (arglist)
emit_move_insn (dest, addr);
if (flag_check_memory_usage)
- emit_library_call (chkr_set_right_libfunc, 1, VOIDmode, 3, dest,
- ptr_mode, GEN_INT (GET_MODE_SIZE (ptr_mode)),
+ emit_library_call (chkr_set_right_libfunc, 1, VOIDmode, 3,
+ dest, ptr_mode,
+ GEN_INT (GET_MODE_SIZE (ptr_mode)),
TYPE_MODE (sizetype),
- GEN_INT (MEMORY_USE_RW), QImode);
+ GEN_INT (MEMORY_USE_RW),
+ TYPE_MODE (integer_type_node));
/* Store the argsize as the __va_offset member. */
dest = change_address (block, TYPE_MODE (integer_type_node),
@@ -1765,12 +1766,13 @@ alpha_builtin_saveregs (arglist)
emit_move_insn (dest, argsize);
if (flag_check_memory_usage)
- emit_library_call (chkr_set_right_libfunc, 1, VOIDmode, 3, dest,
- ptr_mode,
+ emit_library_call (chkr_set_right_libfunc, 1, VOIDmode, 3,
+ dest, ptr_mode,
GEN_INT (GET_MODE_SIZE
(TYPE_MODE (integer_type_node))),
TYPE_MODE (sizetype),
- GEN_INT (MEMORY_USE_RW), QImode);
+ GEN_INT (MEMORY_USE_RW),
+ TYPE_MODE (integer_type_node));
/* Return the address of the va_list constructor, but don't put it in a
register. Doing so would fail when not optimizing and produce worse
diff --git a/gcc/config/alpha/alpha.h b/gcc/config/alpha/alpha.h
index 41a9076..339c4a6 100644
--- a/gcc/config/alpha/alpha.h
+++ b/gcc/config/alpha/alpha.h
@@ -747,8 +747,9 @@ enum reg_class { NO_REGS, GENERAL_REGS, FLOAT_REGS, ALL_REGS,
&& (GET_CODE (SUBREG_REG (OUT)) == MEM \
|| (GET_CODE (SUBREG_REG (OUT)) == REG \
&& REGNO (SUBREG_REG (OUT)) >= FIRST_PSEUDO_REGISTER)))) \
- && ((((MODE) == HImode || (MODE) == QImode) && ! TARGET_BWX \
- || ((MODE) == SImode && (CLASS) == FLOAT_REGS)))) \
+ && ((((MODE) == HImode || (MODE) == QImode) \
+ && (! TARGET_BWX || (CLASS) == FLOAT_REGS)) \
+ || ((MODE) == SImode && (CLASS) == FLOAT_REGS))) \
? GENERAL_REGS \
: ((CLASS) == FLOAT_REGS && GET_CODE (OUT) == MEM \
&& GET_CODE (XEXP (OUT, 0)) == AND) ? GENERAL_REGS \
@@ -911,8 +912,9 @@ enum reg_class { NO_REGS, GENERAL_REGS, FLOAT_REGS, ALL_REGS,
#define FUNCTION_VALUE(VALTYPE, FUNC) \
gen_rtx (REG, \
- (INTEGRAL_TYPE_P (VALTYPE) \
- && TYPE_PRECISION (VALTYPE) < BITS_PER_WORD) \
+ ((INTEGRAL_TYPE_P (VALTYPE) \
+ && TYPE_PRECISION (VALTYPE) < BITS_PER_WORD) \
+ || POINTER_TYPE_P (VALTYPE)) \
? word_mode : TYPE_MODE (VALTYPE), \
((TARGET_FPREGS \
&& (TREE_CODE (VALTYPE) == REAL_TYPE \
@@ -2278,7 +2280,7 @@ do { \
#else
/* In OSF/1 v3.2c, the assembler by default does not output file names which
causes mips-tfile to fail. Passing -g to the assembler fixes this problem.
- ??? Stricly speaking, we only need -g if the user specifies -g. Passing
+ ??? Strictly speaking, we need -g only if the user specifies -g. Passing
it always means that we get slightly larger than necessary object files
if the user does not specify -g. If we don't pass -g, then mips-tfile
will need to be fixed to work in this case. Pass -O0 since some
diff --git a/gcc/config/alpha/alpha.md b/gcc/config/alpha/alpha.md
index 5a7218d..2e6b7b7 100644
--- a/gcc/config/alpha/alpha.md
+++ b/gcc/config/alpha/alpha.md
@@ -37,7 +37,7 @@
(const_string "iadd"))
;; The TRAP_TYPE attribute marks instructions that may generate traps
-;; (which are imprecise and may need a trapb if software complention
+;; (which are imprecise and may need a trapb if software completion
;; is desired).
(define_attr "trap" "no,yes" (const_string "no"))
diff --git a/gcc/config/alpha/linux.h b/gcc/config/alpha/linux.h
index 9a8cc36..32428df 100644
--- a/gcc/config/alpha/linux.h
+++ b/gcc/config/alpha/linux.h
@@ -1,5 +1,5 @@
-/* Definitions of target machine for GNU compiler, for Alpha Linux,
- using ECOFF.
+/* Definitions of target machine for GNU compiler, for Alpha Linux-based GNU
+ systems using ECOFF.
Copyright (C) 1996, 1997 Free Software Foundation, Inc.
Contributed by Bob Manson.
@@ -23,7 +23,7 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
#define TARGET_DEFAULT (3 | MASK_GAS)
#undef TARGET_VERSION
-#define TARGET_VERSION fprintf (stderr, " (Linux/Alpha)");
+#define TARGET_VERSION fprintf (stderr, " (GNU/Linux/Alpha)");
#undef CPP_PREDEFINES
#define CPP_PREDEFINES "\
@@ -80,8 +80,7 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
range and so the target is in range of something on the stack.
Omitting the hint saves a bogus branch-prediction cache line load.
- Linux always has an executable stack -- no need for a system call.
- */
+ GNU/Linux always has an executable stack -- no need for a system call. */
#undef INITIALIZE_TRAMPOLINE
#define INITIALIZE_TRAMPOLINE(TRAMP, FNADDR, CXT) \
diff --git a/gcc/config/alpha/vms.h b/gcc/config/alpha/vms.h
index 8a48a1b..8b33a8d2 100644
--- a/gcc/config/alpha/vms.h
+++ b/gcc/config/alpha/vms.h
@@ -89,10 +89,7 @@ Boston, MA 02111-1307, USA. */
#define POINTER_SIZE 32
#define POINTERS_EXTEND_UNSIGNED 0
-/* No data type wants to be aligned rounder than this. */
-#undef BIGGEST_ALIGNMENT
-#define BIGGEST_ALIGNMENT 128 /* X Complex */
-#define MAX_OFILE_ALIGNMENT 524288 /* 8 x 2^16 by DEC Test CD40VRA */
+#define MAX_OFILE_ALIGNMENT 524288 /* 8 x 2^16 by DEC Ada Test CD40VRA */
#undef FIXED_REGISTERS
#define FIXED_REGISTERS \
@@ -213,13 +210,6 @@ extern struct rtx_def *alpha_arg_info_reg_val ();
+ ALPHA_ARG_SIZE (MODE, TYPE, NAMED) \
? 6 - (CUM).num_args : 0)
-#undef ENCODE_SECTION_INFO
-#define ENCODE_SECTION_INFO(DECL) \
-do { \
- if (TREE_CODE (DECL) == FUNCTION_DECL && ! TREE_PUBLIC (DECL)) \
- SYMBOL_REF_FLAG (XEXP (DECL_RTL (DECL), 0)) = 1; \
-} while (0)
-
/* Perform any needed actions needed for a function that is receiving a
variable number of arguments.
@@ -457,28 +447,11 @@ do { \
sprintf ((OUTPUT), "%s___%d", (NAME), (LABELNO)))
#undef ASM_SPEC
-#define ASM_SPEC "-nocpp %{pg}"
-
#undef ASM_FINAL_SPEC
-
-#define OPTIMIZATION_OPTIONS \
-{ \
- write_symbols = PREFERRED_DEBUGGING_TYPE; \
- debug_info_level = (enum debug_info_level) 2; \
-}
-
-#undef OVERRIDE_OPTIONS
-#define OVERRIDE_OPTIONS \
-{ \
- if (write_symbols == NO_DEBUG) \
- debug_info_level = (enum debug_info_level) 0; \
- override_options (); \
-}
-
#undef LINK_SPEC
-#define LINK_SPEC "%{g3:-g3} %{g0:-g0} %{shared:-shared} %{v:-v}"
-
#undef STARTFILE_SPEC
+#define ASM_SPEC "-nocpp %{pg}"
+#define LINK_SPEC "%{g3:-g3} %{g0:-g0} %{shared:-shared} %{v:-v}"
/* Define the names of the division and modulus functions. */
#define DIVSI3_LIBCALL "OTS$DIV_I"
diff --git a/gcc/config/alpha/xm-alpha.h b/gcc/config/alpha/xm-alpha.h
index 2cf8917..4bf20c0 100644
--- a/gcc/config/alpha/xm-alpha.h
+++ b/gcc/config/alpha/xm-alpha.h
@@ -71,14 +71,6 @@ extern void *malloc (), *realloc (), *calloc ();
#include "string.h"
#endif
-/* OSF/1 has vprintf. */
-
-#define HAVE_VPRINTF
-
-/* OSF/1 has putenv. */
-
-#define HAVE_PUTENV
-
/* OSF/1 is POSIX.1 compliant. */
#define POSIX
diff --git a/gcc/config/arc/arc.c b/gcc/config/arc/arc.c
index 8159585..7272cc9 100644
--- a/gcc/config/arc/arc.c
+++ b/gcc/config/arc/arc.c
@@ -1118,7 +1118,7 @@ arc_output_function_prologue (file, size)
if (size == 0 && gmask)
abort ();
- /* Allocate space for register argumenets if this is a variadic function. */
+ /* Allocate space for register arguments if this is a variadic function. */
if (current_frame_info.pretend_size != 0)
fprintf (file, "\tsub %s,%s,%d\n",
sp_str, sp_str, current_frame_info.pretend_size);
@@ -1565,7 +1565,7 @@ arc_print_operand (file, x, code)
switch (code)
{
case '#' :
- /* Conditional brances. For now these are equivalent. */
+ /* Conditional branches. For now these are equivalent. */
case '*' :
/* Unconditional branches. Output the appropriate delay slot suffix. */
if (!final_sequence || XVECLEN (final_sequence, 0) == 1)
@@ -1971,7 +1971,7 @@ arc_final_prescan_insn (insn, opvec, noperands)
if (GET_CODE (insn) != JUMP_INSN)
return;
- /* This jump might be paralled with a clobber of the condition codes,
+ /* This jump might be paralleled with a clobber of the condition codes,
the jump should always come first. */
if (GET_CODE (body) == PARALLEL && XVECLEN (body, 0) > 0)
body = XVECEXP (body, 0, 0);
@@ -2161,7 +2161,7 @@ arc_final_prescan_insn (insn, opvec, noperands)
/* Restore recog_operand. Getting the attributes of other insns can
destroy this array, but final.c assumes that it remains intact
- accross this call; since the insn has been recognized already we
+ across this call; since the insn has been recognized already we
call insn_extract direct. */
insn_extract (insn);
}
diff --git a/gcc/config/arm/arm.c b/gcc/config/arm/arm.c
index ac43337..b73da5b 100644
--- a/gcc/config/arm/arm.c
+++ b/gcc/config/arm/arm.c
@@ -1,7 +1,7 @@
/* Output routines for GCC for ARM/RISCiX.
Copyright (C) 1991, 93, 94, 95, 96, 1997 Free Software Foundation, Inc.
Contributed by Pieter `Tiggr' Schoenmakers (rcpieter@win.tue.nl)
- and Martin Simmons (@harleqn.co.uk).
+ and Martin Simmons (@harleqn.co.uk).
More major hacks by Richard Earnshaw (rwe11@cl.cam.ac.uk)
This file is part of GNU CC.
@@ -176,7 +176,7 @@ static struct processors all_procs[] =
{"arm600", PROCESSOR_ARM6, FL_CO_PROC | FL_MODE32 | FL_MODE26},
{"arm610", PROCESSOR_ARM6, FL_MODE32 | FL_MODE26},
{"arm7", PROCESSOR_ARM7, FL_CO_PROC | FL_MODE32 | FL_MODE26},
- /* arm7m doesn't exist on its own, only in conjuction with D, (and I), but
+ /* arm7m doesn't exist on its own, only in conjunction with D, (and I), but
those don't alter the code, so it is sometimes known as the arm7m */
{"arm7m", PROCESSOR_ARM7, (FL_CO_PROC | FL_FAST_MULT | FL_MODE32
| FL_MODE26)},
@@ -1302,10 +1302,12 @@ arm_finalize_pic ()
l1 = gen_label_rtx ();
global_offset_table = gen_rtx (SYMBOL_REF, Pmode, "_GLOBAL_OFFSET_TABLE_");
+ /* The PC contains 'dot'+8, but the label L1 is on the next
+ instruction, so the offset is only 'dot'+4. */
pic_tmp = gen_rtx (CONST, VOIDmode,
gen_rtx (PLUS, Pmode,
gen_rtx (LABEL_REF, VOIDmode, l1),
- GEN_INT (8)));
+ GEN_INT (4)));
pic_tmp2 = gen_rtx (CONST, VOIDmode,
gen_rtx (PLUS, Pmode,
global_offset_table,
@@ -3050,7 +3052,7 @@ gen_rotated_half_load (memref)
base = XEXP (base, 0);
}
- /* If we aren't allowed to generate unalligned addresses, then fail. */
+ /* If we aren't allowed to generate unaligned addresses, then fail. */
if (TARGET_SHORT_BY_BYTES
&& ((BYTES_BIG_ENDIAN ? 1 : 0) ^ ((offset & 2) == 0)))
return NULL;
@@ -3075,7 +3077,7 @@ select_dominance_cc_mode (op, x, y, cond_or)
/* Currently we will probably get the wrong result if the individual
comparisons are not simple. This also ensures that it is safe to
- reverse a comparions if necessary. */
+ reverse a comparison if necessary. */
if ((arm_select_cc_mode (cond1 = GET_CODE (x), XEXP (x, 0), XEXP (x, 1))
!= CCmode)
|| (arm_select_cc_mode (cond2 = GET_CODE (y), XEXP (y, 0), XEXP (y, 1))
@@ -3191,10 +3193,10 @@ arm_select_cc_mode (op, x, y)
|| GET_CODE (x) == ROTATERT))
return CC_SWPmode;
- /* This is a special case, that is used by combine to alow a
- comarison of a shifted byte load to be split into a zero-extend
+ /* This is a special case that is used by combine to allow a
+ comparison of a shifted byte load to be split into a zero-extend
followed by a comparison of the shifted integer (only valid for
- equalities and unsigned inequalites. */
+ equalities and unsigned inequalities). */
if (GET_MODE (x) == SImode
&& GET_CODE (x) == ASHIFT
&& GET_CODE (XEXP (x, 1)) == CONST_INT && INTVAL (XEXP (x, 1)) == 24
@@ -5940,7 +5942,7 @@ aof_data_section ()
/* The AOF assembler is religiously strict about declarations of
imported and exported symbols, so that it is impossible to declare
- a function as imported near the begining of the file, and then to
+ a function as imported near the beginning of the file, and then to
export it later on. It is, however, possible to delay the decision
until all the functions in the file have been compiled. To get
around this, we maintain a list of the imports and exports, and
diff --git a/gcc/config/i386/cygwin32.h b/gcc/config/i386/cygwin32.h
index 864ff95..56064be 100644
--- a/gcc/config/i386/cygwin32.h
+++ b/gcc/config/i386/cygwin32.h
@@ -41,6 +41,9 @@ Boston, MA 02111-1307, USA. */
-D__cdecl=__attribute__((__cdecl__)) \
-Asystem(winnt) -Acpu(i386) -Amachine(i386)"
+#undef CPP_SPEC
+#define CPP_SPEC "-remap %(cpp_cpu) %[cpp_cpu] %{posix:-D_POSIX_SOURCE}"
+
/* We have to dynamic link to get to the system DLLs. All of libc, libm and
the Unix stuff is in cygwin.dll. The import library is called
'libcygwin.a'. For Windows applications, include more libraries, but
diff --git a/gcc/config/i386/i386.c b/gcc/config/i386/i386.c
index fc10a9c..a4ec3b6 100644
--- a/gcc/config/i386/i386.c
+++ b/gcc/config/i386/i386.c
@@ -35,7 +35,6 @@ Boston, MA 02111-1307, USA. */
#include "flags.h"
#include "except.h"
#include "function.h"
-#include "dwarf2.h"
#ifdef EXTRA_CONSTRAINT
/* If EXTRA_CONSTRAINT is defined, then the 'S'
@@ -4841,7 +4840,7 @@ reg_mentioned_in_mem (reg, rtl)
return 0;
}
-/* Output the approprate insns for doing strlen if not just doing repnz; scasb
+/* Output the appropriate insns for doing strlen if not just doing repnz; scasb
operands[0] = result, initialized with the startaddress
operands[1] = alignment of the address.
@@ -4896,7 +4895,7 @@ output_strlen_unroll (operands)
therefore use andl rather than andb. */
output_asm_insn (AS2 (and%L1,%4,%1), xops);
- /* Is aligned to 4-byte adress when zero */
+ /* Is aligned to 4-byte address when zero */
output_asm_insn (AS1 (je,%l8), xops);
/* Side-effect even Parity when %eax == 3 */
@@ -4916,7 +4915,7 @@ output_strlen_unroll (operands)
check if is aligned to 4 - byte. */
output_asm_insn (AS2 (and%L1,%3,%1), xops);
- /* Is aligned to 4-byte adress when zero */
+ /* Is aligned to 4-byte address when zero */
output_asm_insn (AS1 (je,%l8), xops);
}
diff --git a/gcc/config/i386/i386.h b/gcc/config/i386/i386.h
index 105bce1..9bfef4e 100644
--- a/gcc/config/i386/i386.h
+++ b/gcc/config/i386/i386.h
@@ -207,6 +207,8 @@ extern int target_flags;
{ "no-debug-arg", -MASK_DEBUG_ARG }, \
{ "stack-arg-probe", MASK_STACK_PROBE }, \
{ "no-stack-arg-probe", -MASK_STACK_PROBE }, \
+ { "windows", 0 }, \
+ { "dll", 0 }, \
SUBTARGET_SWITCHES \
{ "", MASK_SCHEDULE_PROLOGUE | TARGET_DEFAULT}}
diff --git a/gcc/config/i386/rtems.h b/gcc/config/i386/rtems.h
index ada2d9f..b31ceb9 100644
--- a/gcc/config/i386/rtems.h
+++ b/gcc/config/i386/rtems.h
@@ -1,4 +1,4 @@
-/* Definitions for rtems targetting an Intel i386 using coff.
+/* Definitions for rtems targeting an Intel i386 using coff.
Copyright (C) 1996, 1997 Free Software Foundation, Inc.
Contributed by Joel Sherrill (joel@OARcorp.com).
diff --git a/gcc/config/i386/sco5.h b/gcc/config/i386/sco5.h
index 5faa7f7..d2bb159 100644
--- a/gcc/config/i386/sco5.h
+++ b/gcc/config/i386/sco5.h
@@ -289,8 +289,8 @@ do { \
NAME whose size is SIZE bytes and alignment is ALIGN bytes.
Try to use asm_output_aligned_bss to implement this macro. */
-#define ASM_OUTPUT_ALIGNED_BSS(FILE, DECL, NAME, SIZE, ALIGN) \
- asm_output_aligned_bss (FILE, DECL, NAME, SIZE, ALIGN)
+#define ASM_OUTPUT_ALIGNED_BSS(FILE, DECL, NAME, SIZE, ALIGN) \
+asm_output_aligned_bss (FILE, DECL, NAME, SIZE, ALIGN)
#undef ESCAPES
#define ESCAPES \
@@ -694,7 +694,7 @@ dtors_section () \
#undef NO_IMPLICIT_EXTERN_C
#define NO_IMPLICIT_EXTERN_C 1
-/* JKJ FIXME - examine the rammifications of RETURN_IN_MEMORY and
+/* JKJ FIXME - examine the ramifications of RETURN_IN_MEMORY and
RETURN_POPS_ARGS */
#undef RETURN_POPS_ARGS
diff --git a/gcc/config/i386/xm-dos.h b/gcc/config/i386/xm-dos.h
index e6e06f4..a734a81 100644
--- a/gcc/config/i386/xm-dos.h
+++ b/gcc/config/i386/xm-dos.h
@@ -1,8 +1,5 @@
#include "i386/xm-i386.h"
-/* Inhibit cccp.c's definition of putenv. */
-#define HAVE_PUTENV
-
/* Use semicolons to separate elements of a path. */
#define PATH_SEPARATOR ';'
diff --git a/gcc/config/i386/xm-mingw32.h b/gcc/config/i386/xm-mingw32.h
index 75ccd1f..47356f5 100644
--- a/gcc/config/i386/xm-mingw32.h
+++ b/gcc/config/i386/xm-mingw32.h
@@ -33,20 +33,13 @@ Boston, MA 02111-1307, USA. */
#define USE_PROTOTYPES 1
#endif
-#ifndef HAVE_VPRINTF
-#define HAVE_VPRINTF 1
-#endif
-
#define NO_SYS_SIGLIST 1
-#define bcmp(a,b,c) memcmp (a,b,c)
-#define bcopy(a,b,c) memcpy (b,a,c)
-#define bzero(a,b) memset (a,0,b)
-#define index strchr
-#define rindex strrchr
-#define kill(a,b) raise(b)
#define link(a,b) -1
#define environ _environ
/* Even though we support "/", allow "\" since everybody tests both. */
#define DIR_SEPARATOR '\\'
#define EXECUTABLE_SUFFIX ".exe"
+
+#undef PATH_SEPARATOR
+#define PATH_SEPARATOR ';'
diff --git a/gcc/config/i960/rtems.h b/gcc/config/i960/rtems.h
index 0c52cef..7147068 100644
--- a/gcc/config/i960/rtems.h
+++ b/gcc/config/i960/rtems.h
@@ -1,4 +1,4 @@
-/* Definitions for rtems targetting an Intel i960.
+/* Definitions for rtems targeting an Intel i960.
Copyright (C) 1996, 1997 Free Software Foundation, Inc.
Contributed by Joel Sherrill (joel@OARcorp.com).
diff --git a/gcc/config/m68k/linux.h b/gcc/config/m68k/linux.h
index 9ba66f7..837712a 100644
--- a/gcc/config/m68k/linux.h
+++ b/gcc/config/m68k/linux.h
@@ -1,4 +1,5 @@
-/* Definitions for Motorola 68k running Linux with ELF format.
+/* Definitions for Motorola 68k running Linux-based GNU systems with
+ ELF format.
Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
This file is part of GNU CC.
@@ -30,7 +31,7 @@ Boston, MA 02111-1307, USA. */
#include <linux.h> /* some common stuff */
#undef TARGET_VERSION
-#define TARGET_VERSION fprintf (stderr, " (68k Linux/ELF)");
+#define TARGET_VERSION fprintf (stderr, " (68k GNU/Linux with ELF)");
/* 68020 with 68881 */
#define TARGET_DEFAULT (MASK_BITFIELD|MASK_68881|MASK_68020)
@@ -135,7 +136,7 @@ Boston, MA 02111-1307, USA. */
"%{v:-V} %{Qy:} %{!Qn:-Qy} %{n} %{T} %{Ym,*} %{Yd,*} %{Wa,*:%*} \
%{m68040} %{m68060:-m68040}"
-/* Provide a LINK_SPEC appropriate for Linux. Here we provide support
+/* Provide a LINK_SPEC appropriate for GNU/Linux. Here we provide support
for the special GCC options -static and -shared, which allow us to
link things in one of these three modes by applying the appropriate
combinations of options at link-time. We like to support here for
diff --git a/gcc/config/m68k/m68k.c b/gcc/config/m68k/m68k.c
index 605369f..4d958f1 100644
--- a/gcc/config/m68k/m68k.c
+++ b/gcc/config/m68k/m68k.c
@@ -32,7 +32,7 @@ Boston, MA 02111-1307, USA. */
#include "insn-flags.h"
#include "output.h"
#include "insn-attr.h"
-#include "dwarf2.h"
+#include "tree.h"
/* Needed for use_return_insn. */
#include "flags.h"
@@ -1313,6 +1313,8 @@ legitimize_pic_address (orig, mode, reg)
gen_rtx (PLUS, Pmode,
pic_offset_table_rtx, orig));
current_function_uses_pic_offset_table = 1;
+ if (reload_in_progress)
+ regs_ever_live[PIC_OFFSET_TABLE_REGNUM] = 1;
RTX_UNCHANGING_P (pic_ref) = 1;
emit_move_insn (reg, pic_ref);
return reg;
diff --git a/gcc/config/m68k/m68k.h b/gcc/config/m68k/m68k.h
index 6004aaa..8c9cad0 100644
--- a/gcc/config/m68k/m68k.h
+++ b/gcc/config/m68k/m68k.h
@@ -280,8 +280,8 @@ extern int target_flags;
/* No data type wants to be aligned rounder than this.
Most published ABIs say that ints should be aligned on 16 bit
- boundries, but cpus with 32 bit busses get better performance
- aligned on 32 bit boundries. Coldfires without a misalignment
+ boundaries, but cpus with 32 bit busses get better performance
+ aligned on 32 bit boundaries. Coldfires without a misalignment
module require 32 bit alignment. */
#define BIGGEST_ALIGNMENT (TARGET_ALIGN_INT ? 32 : 16)
@@ -378,7 +378,7 @@ extern int target_flags;
and are not available for the register allocator.
On the 68000, only the stack pointer is such. */
-/* fpa0 is also reserved so that it can be used to move shit back and
+/* fpa0 is also reserved so that it can be used to move data back and
forth between high fpa regs and everything else. */
#define FIXED_REGISTERS \
diff --git a/gcc/config/m68k/rtems.h b/gcc/config/m68k/rtems.h
index 7472346..77c02f8 100644
--- a/gcc/config/m68k/rtems.h
+++ b/gcc/config/m68k/rtems.h
@@ -1,4 +1,4 @@
-/* Definitions for rtems targetting a Motorola m68k using coff.
+/* Definitions for rtems targeting a Motorola m68k using coff.
Copyright (C) 1996, 1997 Free Software Foundation, Inc.
Contributed by Joel Sherrill (joel@OARcorp.com).
diff --git a/gcc/config/m68k/xm-mot3300.h b/gcc/config/m68k/xm-mot3300.h
index 0c1ec67..8f4c0a4 100644
--- a/gcc/config/m68k/xm-mot3300.h
+++ b/gcc/config/m68k/xm-mot3300.h
@@ -1,6 +1,6 @@
/* Configuration for GNU C-compiler for Motorola 68000 family.
SysV68 Motorola 3300 Delta Series
- Copyright (C) 1994, 1995, 1996 Free Software Foundation, Inc.
+ Copyright (C) 1994, 1995, 1996, 1997 Free Software Foundation, Inc.
This file is part of GNU CC.
@@ -24,13 +24,6 @@ Boston, MA 02111-1307, USA. */
#include "m68k/xm-m68k.h"
-#define bcopy(a,b,c) memcpy (b,a,c)
-#define bzero(a,b) memset (a,0,b)
-#define bcmp(a,b,c) memcmp (a,b,c)
-
-#define rindex strrchr
-#define index strchr
-
#define NO_SYS_SIGLIST
/* do not use alloca from -lPW with cc, because function epilogues use %sp */
diff --git a/gcc/config/m88k/dgux.h b/gcc/config/m88k/dgux.h
index 449bd1d..3e4c66e 100644
--- a/gcc/config/m88k/dgux.h
+++ b/gcc/config/m88k/dgux.h
@@ -1,6 +1,6 @@
/* Definitions of target machine for GNU compiler.
Motorola m88100 running DG/UX.
- Copyright (C) 1988, 92, 93, 94, 95, 1996 Free Software Foundation, Inc.
+ Copyright (C) 1988, 92, 93, 94, 95, 96, 1997 Free Software Foundation, Inc.
Contributed by Michael Tiemann (tiemann@mcc.com)
Currently maintained by (gcc@dg-rtp.dg.com)
@@ -30,7 +30,7 @@ Boston, MA 02111-1307, USA. */
(TARGET_SVR4 ? DWARF_DEBUG : SDB_DEBUG)
#ifndef VERSION_INFO2
-#define VERSION_INFO2 "$Revision: 1.1.1.1 $"
+#define VERSION_INFO2 "$Revision: 1.3 $"
#endif
#ifndef NO_BUGS
#define AS_BUG_IMMEDIATE_LABEL
@@ -134,6 +134,8 @@ Boston, MA 02111-1307, USA. */
{ "startfile_default", STARTFILE_DEFAULT_SPEC }, \
{ "startfile_crtbegin", STARTFILE_CRTBEGIN_SPEC }
+/* Keep this left justified, no white space is allowed between
+ the arguments to the -Wc option */
#define ASM_CPU_SPEC "\
%{v:-V}\
%{g:\
diff --git a/gcc/config/m88k/m88k.c b/gcc/config/m88k/m88k.c
index 2fd0824..45938a1 100644
--- a/gcc/config/m88k/m88k.c
+++ b/gcc/config/m88k/m88k.c
@@ -2650,13 +2650,15 @@ m88k_builtin_saveregs (arglist)
emit_library_call (chkr_set_right_libfunc, 1, VOIDmode, 3,
block, ptr_mode,
GEN_INT (3 * UNITS_PER_WORD), TYPE_MODE (sizetype),
- GEN_INT (MEMORY_USE_RW), QImode);
+ GEN_INT (MEMORY_USE_RW),
+ TYPE_MODE (integer_type_node));
if (fixed < 8)
emit_library_call (chkr_set_right_libfunc, 1, VOIDmode, 3,
dest, ptr_mode,
GEN_INT (UNITS_PER_WORD * (8 - fixed)),
TYPE_MODE (sizetype),
- GEN_INT (MEMORY_USE_RW), QImode);
+ GEN_INT (MEMORY_USE_RW),
+ TYPE_MODE (integer_type_node));
}
/* Return the address of the va_list constructor, but don't put it in a
diff --git a/gcc/config/m88k/xm-m88k.h b/gcc/config/m88k/xm-m88k.h
index aff8e5f..b330f59 100644
--- a/gcc/config/m88k/xm-m88k.h
+++ b/gcc/config/m88k/xm-m88k.h
@@ -1,6 +1,6 @@
/* Configuration for GNU compiler.
Motorola m88100 in an 88open OCS/BCS environment.
- Copyright (C) 1988, 1989, 1990, 1991, 1993 Free Software Foundation, Inc.
+ Copyright (C) 1988, 89, 90, 91, 93, 1997 Free Software Foundation, Inc.
This file is part of GNU CC.
@@ -37,14 +37,6 @@ Boston, MA 02111-1307, USA. */
#define SUCCESS_EXIT_CODE 0
#define FATAL_EXIT_CODE 33
-/* Use System V memory functions. */
-#define bcopy(a,b,c) memcpy (b,a,c)
-#define bzero(a,b) memset (a,0,b)
-#define bcmp(a,b,c) memcmp (a,b,c)
-
-#define rindex strrchr
-#define index strchr
-
/* The 88open BCS (and ABI) environment doesn't support BSD features
(vfork, getrusage), so use USG. The Omron Luna/88k is BSD though. */
#ifndef luna88k
@@ -54,9 +46,6 @@ Boston, MA 02111-1307, USA. */
#define NO_SYS_SIGLIST
#endif
-/* Define HAVE_VPRINTF if it is available on host system. */
-#define HAVE_VPRINTF
-
/* If not compiled with GNU C, use the C alloca */
#ifndef __GNUC__
#define USE_C_ALLOCA
diff --git a/gcc/config/mips/iris6.h b/gcc/config/mips/iris6.h
index e66481f..5bc733c 100644
--- a/gcc/config/mips/iris6.h
+++ b/gcc/config/mips/iris6.h
@@ -1,5 +1,5 @@
/* Definitions of target machine for GNU compiler. Iris version 6.
- Copyright (C) 1994, 1995, 1996 Free Software Foundation, Inc.
+ Copyright (C) 1994, 1995, 1996, 1997 Free Software Foundation, Inc.
This file is part of GNU CC.
@@ -140,7 +140,7 @@ Boston, MA 02111-1307, USA. */
} while (0)
/* Tell function_prologue in mips.c that we have already output the .ent/.end
- psuedo-ops. */
+ pseudo-ops. */
#define FUNCTION_NAME_ALREADY_DECLARED
#undef SET_ASM_OP /* Has no equivalent. See ASM_OUTPUT_DEF below. */
diff --git a/gcc/config/mips/mips.c b/gcc/config/mips/mips.c
index 706a9bf..78639d4 100644
--- a/gcc/config/mips/mips.c
+++ b/gcc/config/mips/mips.c
@@ -3687,7 +3687,7 @@ override_options ()
}
/* This optimization requires a linker that can support a R_MIPS_LO16
- relocation which is not immediately preceeded by a R_MIPS_HI16 relocation.
+ relocation which is not immediately preceded by a R_MIPS_HI16 relocation.
GNU ld has this support, but not all other MIPS linkers do, so we enable
this optimization only if the user requests it, or if GNU ld is the
standard linker for this configuration. */
diff --git a/gcc/config/mips/mips.h b/gcc/config/mips/mips.h
index 59b2474..44ac3b9 100644
--- a/gcc/config/mips/mips.h
+++ b/gcc/config/mips/mips.h
@@ -1448,7 +1448,7 @@ do { \
On the MIPS, all general registers are one word long. Except on
the R4000 with the FR bit set, the floating point uses register
- pairs, with the second register not being allocatable. */
+ pairs, with the second register not being allocable. */
#define HARD_REGNO_NREGS(REGNO, MODE) \
(! FP_REG_P (REGNO) \
diff --git a/gcc/config/mips/mips.md b/gcc/config/mips/mips.md
index 27958ca..5dfbdef 100644
--- a/gcc/config/mips/mips.md
+++ b/gcc/config/mips/mips.md
@@ -255,7 +255,7 @@
(and (eq_attr "mode" "DI") (eq_attr "cpu" "r5000")))
68 68)
-;; The R4300 does *NOT* have a seperate Floating Point Unit, instead
+;; The R4300 does *NOT* have a separate Floating Point Unit, instead
;; the FP hardware is part of the normal ALU circuitry. This means FP
;; instructions affect the pipe-line, and no functional unit
;; parallelism can occur on R4300 processors. To force GCC into coding
diff --git a/gcc/config/mips/rtems64.h b/gcc/config/mips/rtems64.h
index dd21562..6433ed5 100644
--- a/gcc/config/mips/rtems64.h
+++ b/gcc/config/mips/rtems64.h
@@ -1,4 +1,4 @@
-/* Definitions for rtems targetting a MIPS ORION using ecoff.
+/* Definitions for rtems targeting a MIPS ORION using ecoff.
Copyright (C) 1996, 1997 Free Software Foundation, Inc.
Contributed by Joel Sherrill (joel@OARcorp.com).
diff --git a/gcc/config/mips/xm-mips.h b/gcc/config/mips/xm-mips.h
index d8eb4b5..e10f78e 100644
--- a/gcc/config/mips/xm-mips.h
+++ b/gcc/config/mips/xm-mips.h
@@ -1,5 +1,5 @@
/* Configuration for GNU C-compiler for MIPS Rx000 family
- Copyright (C) 1989, 1990, 1991, 1993 Free Software Foundation, Inc.
+ Copyright (C) 1989, 1990, 1991, 1993, 1997 Free Software Foundation, Inc.
This file is part of GNU CC.
@@ -77,8 +77,6 @@ extern char * alloca ();
/* Say if we have vprintf. BSD Mips targets probably don't have vfprintf. */
#if defined(__OSF1__) || defined(__OSF__) || defined(__osf__) || defined(bsd4_4)
-#define HAVE_VPRINTF
-#define HAVE_PUTENV
#else
#define NO_STAB_H /* mips doesn't typically have stab.h */
diff --git a/gcc/config/mn10200/mn10200.c b/gcc/config/mn10200/mn10200.c
index c177607..5435f77 100644
--- a/gcc/config/mn10200/mn10200.c
+++ b/gcc/config/mn10200/mn10200.c
@@ -896,7 +896,7 @@ secondary_reload_class (class, mode, in, input)
&& class == ADDRESS_REGS)
return DATA_REGS;
- /* Address register stores which are not PSImode need a scrach register. */
+ /* Address register stores which are not PSImode need a scratch register. */
if (! input
&& GET_CODE (in) == MEM
&& (mode != PSImode)
diff --git a/gcc/config/mn10200/mn10200.h b/gcc/config/mn10200/mn10200.h
index 23818d8..2c51843 100644
--- a/gcc/config/mn10200/mn10200.h
+++ b/gcc/config/mn10200/mn10200.h
@@ -1,5 +1,4 @@
-/* Definitions of target machine for GNU compiler.
- Matsushita MN10200 series
+/* Definitions of target machine for GNU compiler. Matsushita MN10200 series
Copyright (C) 1997 Free Software Foundation, Inc.
Contributed by Jeff Law (law@cygnus.com).
@@ -954,7 +953,7 @@ do { char dstr[30]; \
if ((LOG) != 0) \
fprintf (FILE, "\t.align %d\n", (LOG))
-/* We don't have to worry about dbx compatability for the mn10200. */
+/* We don't have to worry about dbx compatibility for the mn10200. */
#define DEFAULT_GDB_EXTENSIONS 1
/* Use stabs debugging info by default. */
diff --git a/gcc/config/mn10200/mn10200.md b/gcc/config/mn10200/mn10200.md
index 443fc8b..9dc753c 100644
--- a/gcc/config/mn10200/mn10200.md
+++ b/gcc/config/mn10200/mn10200.md
@@ -30,7 +30,7 @@
;; none_0hit - insn does not affect cc but it does modify operand 0
;; This attribute is used to keep track of when operand 0 changes.
;; See the description of NOTICE_UPDATE_CC for more info.
-;; set_znv - sets z,n,v to useable values; c is unknown.
+;; set_znv - sets z,n,v to usable values; c is unknown.
;; set_zn - sets z,n to usable values; v,c is unknown.
;; compare - compare instruction
;; clobber - value of cc is unknown
@@ -1708,7 +1708,7 @@
;; a few times, then truncating the value to PSImode.
;;
;; This first pattern combines the shifting & truncation operations, by
-;; itself it is a win because the shifts end up occuring in PSImode instead
+;; itself it is a win because the shifts end up occurring in PSImode instead
;; of SImode. However, it has the secondary effect of giving us the
;; opportunity to match patterns which allow us to remove the initial
;; extension completely, which is a big win.
diff --git a/gcc/config/mn10300/mn10300.c b/gcc/config/mn10300/mn10300.c
index 5822058..d813f2c 100644
--- a/gcc/config/mn10300/mn10300.c
+++ b/gcc/config/mn10300/mn10300.c
@@ -581,7 +581,7 @@ expand_epilogue ()
the stack with one instruction.
?!? Only save registers which are actually used. Reduces
- stack requireents and is faster. */
+ stack requirements and is faster. */
if (regs_ever_live[2] || regs_ever_live[3]
|| regs_ever_live[6] || regs_ever_live[7]
|| frame_pointer_needed)
diff --git a/gcc/config/mn10300/mn10300.h b/gcc/config/mn10300/mn10300.h
index ed98a66..f244990 100644
--- a/gcc/config/mn10300/mn10300.h
+++ b/gcc/config/mn10300/mn10300.h
@@ -1,5 +1,4 @@
-/* Definitions of target machine for GNU compiler.
- Matsushita MN10300 series
+/* Definitions of target machine for GNU compiler. Matsushita MN10300 series
Copyright (C) 1996, 1997 Free Software Foundation, Inc.
Contributed by Jeff Law (law@cygnus.com).
@@ -937,7 +936,7 @@ do { char dstr[30]; \
if ((LOG) != 0) \
fprintf (FILE, "\t.align %d\n", (LOG))
-/* We don't have to worry about dbx compatability for the mn10300. */
+/* We don't have to worry about dbx compatibility for the mn10300. */
#define DEFAULT_GDB_EXTENSIONS 1
/* Use stabs debugging info by default. */
diff --git a/gcc/config/mn10300/mn10300.md b/gcc/config/mn10300/mn10300.md
index 1547ad0..726418f 100644
--- a/gcc/config/mn10300/mn10300.md
+++ b/gcc/config/mn10300/mn10300.md
@@ -1,4 +1,4 @@
-; GCC machine description for Matsushita MN10300
+;; GCC machine description for Matsushita MN10300
;; Copyright (C) 1996, 1997 Free Software Foundation, Inc.
;; Contributed by Jeff Law (law@cygnus.com).
@@ -30,8 +30,8 @@
;; none_0hit - insn does not affect cc but it does modify operand 0
;; This attribute is used to keep track of when operand 0 changes.
;; See the description of NOTICE_UPDATE_CC for more info.
-;; set_znv - insn sets z,n,v to useable values; c is unusable.
-;; set_zn - insn sets z,n to useable values; v,c are unuseable.
+;; set_znv - insn sets z,n,v to usable values; c is unusable.
+;; set_zn - insn sets z,n to usable values; v,c are unusable.
;; compare - compare instruction
;; invert -- like compare, but flags are inverted.
;; clobber - value of cc is unknown
diff --git a/gcc/config/pa/pa-hpux10.h b/gcc/config/pa/pa-hpux10.h
index c4b8ddd..9a2af5d 100644
--- a/gcc/config/pa/pa-hpux10.h
+++ b/gcc/config/pa/pa-hpux10.h
@@ -1,5 +1,5 @@
/* Definitions of target machine for GNU compiler, for HP PA-RISC 1.1
- Copyright (C) 1995, 1996 Free Software Foundation, Inc.
+ Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
Contributed by Tim Moore (moore@defmacro.cs.utah.edu)
This file is part of GNU CC.
@@ -20,7 +20,7 @@ the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA. */
/* We can debug dynamically linked executables on hpux9; we also want
- derefercing of a NULL pointer to cause a SEGV. */
+ dereferencing of a NULL pointer to cause a SEGV. */
#undef LINK_SPEC
#if ((TARGET_DEFAULT | TARGET_CPU_DEFAULT) & 1)
#define LINK_SPEC \
diff --git a/gcc/config/pa/pa.c b/gcc/config/pa/pa.c
index 1d65fcb..eb1af93 100644
--- a/gcc/config/pa/pa.c
+++ b/gcc/config/pa/pa.c
@@ -126,17 +126,17 @@ override_options ()
if (flag_pic && (TARGET_NO_SPACE_REGS || TARGET_FAST_INDIRECT_CALLS))
{
- warning ("PIC code generation is not compatable with fast indirect calls\n");
+ warning ("PIC code generation is not compatible with fast indirect calls\n");
}
if (flag_pic && profile_flag)
{
- warning ("PIC code generation is not compatable with profiling\n");
+ warning ("PIC code generation is not compatible with profiling\n");
}
if (TARGET_SPACE && (flag_pic || profile_flag))
{
- warning ("Out of line entry/exit sequences are not compatable\n");
+ warning ("Out of line entry/exit sequences are not compatible\n");
warning ("with PIC or profiling\n");
}
@@ -1885,7 +1885,7 @@ find_addr_reg (addr)
OPERANDS[4] is the size as a CONST_INT
OPERANDS[3] is a register for temporary storage.
OPERANDS[5] is the alignment safe to use, as a CONST_INT.
- OPERNADS[6] is another temporary register. */
+ OPERANDS[6] is another temporary register. */
char *
output_block_move (operands, size_is_constant)
@@ -4324,7 +4324,7 @@ hppa_builtin_saveregs (arglist)
individually as scalar stores.
However, other insns may later load from the same addresses for
- a struture load (passing a struct to a varargs routine).
+ a structure load (passing a struct to a varargs routine).
The alias code assumes that such aliasing can never happen, so we
have to keep memory referencing insns from moving up beyond the
@@ -4335,7 +4335,8 @@ hppa_builtin_saveregs (arglist)
emit_library_call (chkr_set_right_libfunc, 1, VOIDmode, 3,
dest, ptr_mode,
GEN_INT (4 * UNITS_PER_WORD), TYPE_MODE (sizetype),
- GEN_INT (MEMORY_USE_RW), QImode);
+ GEN_INT (MEMORY_USE_RW),
+ TYPE_MODE (integer_type_node));
return copy_to_reg (expand_binop (Pmode, add_optab,
current_function_internal_arg_pointer,
@@ -6041,7 +6042,7 @@ pa_reorg (insns)
continue;
/* Now generate markers for the beginning and end of the
- branc table. */
+ branch table. */
emit_insn_before (gen_begin_brtab (), insn);
emit_insn_after (gen_end_brtab (), insn);
}
@@ -6098,7 +6099,7 @@ pa_combine_instructions (insns)
/* This can get expensive since the basic algorithm is on the
order of O(n^2) (or worse). Only do it for -O2 or higher
- levels of optimizaton. */
+ levels of optimization. */
if (optimize < 2)
return;
diff --git a/gcc/config/pa/pa.h b/gcc/config/pa/pa.h
index 5944448..c286fb9 100644
--- a/gcc/config/pa/pa.h
+++ b/gcc/config/pa/pa.h
@@ -77,7 +77,7 @@ extern int target_flags;
this option will fail miserably if the executable is dynamically linked
or uses nested functions!
- This is also used to trigger agressive unscaled index addressing. */
+ This is also used to trigger aggressive unscaled index addressing. */
#define TARGET_NO_SPACE_REGS (target_flags & 4)
/* Allow unconditional jumps in the delay slots of call instructions. */
@@ -118,7 +118,7 @@ extern int target_flags;
#define TARGET_FAST_INDIRECT_CALLS (target_flags & 1024)
/* Generate code with big switch statements to avoid out of range branches
- occuring within the switch table. */
+ occurring within the switch table. */
#define TARGET_BIG_SWITCH (target_flags & 2048)
/* Macro to define tables used to set the flags.
@@ -281,7 +281,7 @@ extern int target_flags;
or "static /usr/lib/X11R5/libX11.sl".
HPUX 10.20 also has lines like "static branch prediction ..."
- so we filter that out explcitly.
+ so we filter that out explicitly.
We also try to bound our search for libraries with marker
lines. What a pain. */
diff --git a/gcc/config/pa/pa.md b/gcc/config/pa/pa.md
index d1e89a1..0ed6cbd 100644
--- a/gcc/config/pa/pa.md
+++ b/gcc/config/pa/pa.md
@@ -5082,7 +5082,7 @@
/* Must import the magic millicode routine. */
output_asm_insn (\".IMPORT $$sh_func_adrs,MILLICODE\", NULL);
- /* This is absolutely fucking amazing.
+ /* This is absolutely amazing.
First, copy our input parameter into %r29 just in case we don't
need to call $$sh_func_adrs. */
@@ -5138,7 +5138,7 @@
(const_int 0)))
(const_int 32)
-;; PORTABLE_RUTNIME
+;; PORTABLE_RUNTIME
(ne (symbol_ref "TARGET_PORTABLE_RUNTIME")
(const_int 0))
(const_int 40)]
diff --git a/gcc/config/rs6000/linux.h b/gcc/config/rs6000/linux.h
index 0632dce..10474e4 100644
--- a/gcc/config/rs6000/linux.h
+++ b/gcc/config/rs6000/linux.h
@@ -49,7 +49,7 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
#define LINK_OS_DEFAULT_SPEC "%(link_os_linux)"
#undef TARGET_VERSION
-#define TARGET_VERSION fprintf (stderr, " (PowerPC Linux)");
+#define TARGET_VERSION fprintf (stderr, " (PowerPC GNU/Linux)");
/* Define this macro as a C expression for the initializer of an
array of string to tell the driver program which options are
diff --git a/gcc/config/rs6000/rs6000.h b/gcc/config/rs6000/rs6000.h
index 3e7b932..d30af75 100644
--- a/gcc/config/rs6000/rs6000.h
+++ b/gcc/config/rs6000/rs6000.h
@@ -52,7 +52,7 @@ Boston, MA 02111-1307, USA. */
#define CPP_SPEC "%{posix: -D_POSIX_SOURCE} %(cpp_cpu)"
-/* Common CPP definitions used by CPP_SPEC amonst the various targets
+/* Common CPP definitions used by CPP_SPEC among the various targets
for handling -mcpu=xxx switches. */
#define CPP_CPU_SPEC \
"%{!mcpu*: \
@@ -101,7 +101,7 @@ Boston, MA 02111-1307, USA. */
#define CPP_SYSV_DEFAULT_SPEC ""
#endif
-/* Common ASM definitions used by ASM_SPEC amonst the various targets
+/* Common ASM definitions used by ASM_SPEC among the various targets
for handling -mcpu=xxx switches. */
#define ASM_CPU_SPEC \
"%{!mcpu*: \
@@ -242,7 +242,7 @@ extern int target_flags;
if there are more than 16K unique variables/constant in a single module.
This is at the cost of having 2 extra loads and one extra store per
- function, and one less allocatable register. */
+ function, and one less allocable register. */
#define MASK_MINIMAL_TOC 0x00000200
/* Nonzero for the 64bit model: ints, longs, and pointers are 64 bits. */
@@ -424,7 +424,7 @@ extern enum processor_type rs6000_cpu;
extern char *m88k_short_data;
#define TARGET_OPTIONS { { "short-data-", &m88k_short_data } } */
-/* This is meant to be overriden in target specific files. */
+/* This is meant to be overridden in target specific files. */
#ifndef SUBTARGET_OPTIONS
#define SUBTARGET_OPTIONS
#endif
@@ -909,7 +909,7 @@ extern int rs6000_debug_arg; /* debug argument handling */
Also, cr0 is the only condition code register that can be used in
arithmetic insns, so make a separate class for it.
- There is a special 'registrer' (76), which is not a register, but a
+ There is a special 'register' (76), which is not a register, but a
placeholder for memory allocated to convert between floating point and
integral types. This works around a problem where if we allocate memory
with allocate_stack_{local,temp} and the function is an inline function, the
diff --git a/gcc/config/rs6000/rs6000.md b/gcc/config/rs6000/rs6000.md
index cf88a7a..8f71378 100644
--- a/gcc/config/rs6000/rs6000.md
+++ b/gcc/config/rs6000/rs6000.md
@@ -7241,7 +7241,7 @@
DONE;
}")
-;; If we have -mmiminal-toc, we need to reload r30 after a nonlocal goto.
+;; If we have -mminimal-toc, we need to reload r30 after a nonlocal goto.
(define_insn "nonlocal_goto_receiver"
[(unspec_volatile [(const_int 0)] 1)]
diff --git a/gcc/config/rs6000/rtems.h b/gcc/config/rs6000/rtems.h
index 287da25..c00c5ad 100644
--- a/gcc/config/rs6000/rtems.h
+++ b/gcc/config/rs6000/rtems.h
@@ -1,4 +1,4 @@
-/* Definitions for rtems targetting a PowerPC using elf.
+/* Definitions for rtems targeting a PowerPC using elf.
Copyright (C) 1996, 1997 Free Software Foundation, Inc.
Contributed by Joel Sherrill (joel@OARcorp.com).
diff --git a/gcc/config/rs6000/sysv4.h b/gcc/config/rs6000/sysv4.h
index dace380..e9a88a2 100644
--- a/gcc/config/rs6000/sysv4.h
+++ b/gcc/config/rs6000/sysv4.h
@@ -1,5 +1,5 @@
/* Target definitions for GNU compiler for PowerPC running System V.4
- Copyright (C) 1995, 1996 Free Software Foundation, Inc.
+ Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
Contributed by Cygnus Support.
This file is part of GNU CC.
@@ -584,7 +584,7 @@ extern void rs6000_select_rtx_section (), rs6000_select_section ();
we can't check that since not every file that uses
GO_IF_LEGITIMATE_ADDRESS_P includes real.h.
- Unlike AIX, we don't key off of -mmininal-toc, but instead do not
+ Unlike AIX, we don't key off of -mminimal-toc, but instead do not
allow floating point constants in the TOC if -mrelocatable. */
#undef ASM_OUTPUT_SPECIAL_POOL_ENTRY_P
@@ -713,7 +713,7 @@ do { \
} \
} while (0)
-/* Describe how to emit unitialized external linkage items */
+/* Describe how to emit uninitialized external linkage items */
#define ASM_OUTPUT_ALIGNED_BSS(FILE, DECL, NAME, SIZE, ALIGN) \
do { \
ASM_GLOBALIZE_LABEL (FILE, NAME); \
@@ -1030,7 +1030,7 @@ do { \
#undef LINK_SHLIB_SPEC
#ifndef NO_SHARED_LIB_SUPPORT
-/* Shared libaries are default. */
+/* Shared libraries are default. */
#define LINK_SHLIB_SPEC "\
%{!static: %(link_path) %{!R*:%{L*:-R %*}}} \
%{mshlib: } \
@@ -1269,7 +1269,7 @@ do { \
#define CPP_OS_SIM_SPEC ""
#endif
-/* Linux support. */
+/* GNU/Linux support. */
#ifndef LIB_LINUX_SPEC
#define LIB_LINUX_SPEC "%{mnewlib: --start-group -llinux -lc --end-group } %{!mnewlib: -lc }"
#endif
diff --git a/gcc/config/rs6000/xm-cygwin32.h b/gcc/config/rs6000/xm-cygwin32.h
index 9b3c270..677254b 100644
--- a/gcc/config/rs6000/xm-cygwin32.h
+++ b/gcc/config/rs6000/xm-cygwin32.h
@@ -1,6 +1,6 @@
/* Configuration for GNU C-compiler for hosting on Windows NT.
using a unix style C library.
- Copyright (C) 1995 Free Software Foundation, Inc.
+ Copyright (C) 1995, 1997 Free Software Foundation, Inc.
This file is part of GNU CC.
diff --git a/gcc/config/sh/rtems.h b/gcc/config/sh/rtems.h
index be9d8f2..2e864ad 100644
--- a/gcc/config/sh/rtems.h
+++ b/gcc/config/sh/rtems.h
@@ -1,4 +1,4 @@
-/* Definitions for rtems targetting a SH using elf.
+/* Definitions for rtems targeting a SH using elf.
Copyright (C) 1997 Free Software Foundation, Inc.
Contributed by Joel Sherrill (joel@OARcorp.com).
diff --git a/gcc/config/sh/sh.c b/gcc/config/sh/sh.c
index 286195e..7f12528 100644
--- a/gcc/config/sh/sh.c
+++ b/gcc/config/sh/sh.c
@@ -1,5 +1,5 @@
/* Output routines for GCC for Hitachi Super-H.
- Copyright (C) 1993, 1994, 1995, 1996 Free Software Foundation, Inc.
+ Copyright (C) 1993, 1994, 1995, 1996, 1997 Free Software Foundation, Inc.
This file is part of GNU CC.
@@ -1919,7 +1919,7 @@ find_barrier (num_mova, mova, from)
delay slot. This gives 1018. */
/* The branch will always be shortened now that the reference address for
- forward branches is the sucessor address, thus we need no longer make
+ forward branches is the successor address, thus we need no longer make
adjustments to the [sh]i_limit for -O0. */
si_limit = 1018;
@@ -1937,7 +1937,7 @@ find_barrier (num_mova, mova, from)
if (GET_CODE (from) == BARRIER)
{
found_barrier = from;
- /* If we are at the end of the function, or in front of an alignemnt
+ /* If we are at the end of the function, or in front of an alignment
instruction, we need not insert an extra alignment. We prefer
this kind of barrier. */
@@ -2004,7 +2004,7 @@ find_barrier (num_mova, mova, from)
/* We have just passed the barrier in front front of the
ADDR_DIFF_VEC. Since the ADDR_DIFF_VEC is accessed
as data, just like our pool constants, this is a good
- opportunity to accomodate what we have gathered so far.
+ opportunity to accommodate what we have gathered so far.
If we waited any longer, we could end up at a barrier in
front of code, which gives worse cache usage for separated
instruction / data caches. */
@@ -2286,7 +2286,7 @@ regs_used (x, is_dest)
}
/* Create an instruction that prevents redirection of a conditional branch
- to the desitination of the JUMP with address ADDR.
+ to the destination of the JUMP with address ADDR.
If the branch needs to be implemented as an indirect jump, try to find
a scratch register for it.
If NEED_BLOCK is 0, don't do anything unless we need a scratch register.
@@ -2327,7 +2327,7 @@ gen_block_redirect (jump, addr, need_block)
{
rtx scan;
/* Don't look for the stack pointer as a scratch register,
- it would cause trouble if an interrupt occured. */
+ it would cause trouble if an interrupt occurred. */
unsigned try = 0x7fff, used;
int jump_left = flag_expensive_optimizations + 1;
@@ -2385,7 +2385,7 @@ gen_block_redirect (jump, addr, need_block)
/* If the immediate destination is still in range, check for possible
threading with a jump beyond the delay slot insn.
Don't check if we are called recursively; the jump has been or will be
- checked in a different invokation then. */
+ checked in a different invocation then. */
else if (optimize && need_block >= 0)
{
@@ -2406,7 +2406,7 @@ gen_block_redirect (jump, addr, need_block)
rtx reg = gen_rtx (REG, SImode, exact_log2 (dead & -dead));
/* It would be nice if we could convert the jump into an indirect
- jump / far branch right now, and thus exposing all consitituent
+ jump / far branch right now, and thus exposing all constituent
instructions to further optimization. However, reorg uses
simplejump_p to determine if there is an unconditional jump where
it should try to schedule instructions from the target of the
@@ -2936,7 +2936,7 @@ machine_dependent_reorg (first)
}
/* The following processing passes need length information.
- addr_diff_vec_adjust needs to know if insn_addreses is valid. */
+ addr_diff_vec_adjust needs to know if insn_addresses is valid. */
insn_addresses = 0;
/* If not optimizing for space, we want extra alignment for code after
@@ -3076,7 +3076,7 @@ machine_dependent_reorg (first)
/* range of mova is 1020, add 4 because pc counts from address of
second instruction after this one, subtract 2 in case pc is 2
byte aligned. Possible alignment needed for the ADDR_DIFF_VEC
- chancles out with alignment effects of the mova itself. */
+ cancels out with alignment effects of the mova itself. */
if (total > 1022)
{
/* Change the mova into a load, and restart scanning
@@ -3278,7 +3278,7 @@ split_branches (first)
the label if th lABEL_BUSES count drops to zero. There is
always a jump_optimize pass that sets these values, but it
proceeds to delete unreferenced code, and then if not
- optimizeing, to un-delete the deleted instructions, thus
+ optimizing, to un-delete the deleted instructions, thus
leaving labels with too low uses counts. */
if (! optimize)
{
@@ -3936,7 +3936,7 @@ handle_pragma (file, t)
sp_switch -- specifies an alternate stack for an interrupt handler
to run on.
- trap_exit -- use a trapa to exit an interrupt function intead of
+ trap_exit -- use a trapa to exit an interrupt function instead of
an rte instruction. */
int
@@ -4263,7 +4263,7 @@ branch_offset (branch)
while (dest_uid >= uid_align_max || ! uid_align[dest_uid])
{
/* Label might be outside the insn stream, or even in a separate
- insn stream, after a syntax errror. */
+ insn stream, after a syntax error. */
if (! NEXT_INSN (dest))
return 0;
dest = NEXT_INSN (dest), dest_uid = INSN_UID (dest);
diff --git a/gcc/config/sh/sh.h b/gcc/config/sh/sh.h
index 5b46976..a3aa9025 100644
--- a/gcc/config/sh/sh.h
+++ b/gcc/config/sh/sh.h
@@ -404,7 +404,7 @@ do { \
frame pointer register can often be eliminated in favor of the stack
pointer register. Secondly, the argument pointer register can always be
eliminated; it is replaced with either the stack or frame pointer.
- Third, there is the retuen address pointer, which can also be replaced
+ Third, there is the return address pointer, which can also be replaced
with either the stack or the frame pointer. */
/* This is an array of structures. Each structure initializes one pair
diff --git a/gcc/config/sh/sh.md b/gcc/config/sh/sh.md
index 42b866c..ae49456 100644
--- a/gcc/config/sh/sh.md
+++ b/gcc/config/sh/sh.md
@@ -1,5 +1,5 @@
;;- Machine description for the Hitachi SH.
-;; Copyright (C) 1993, 1994, 1995 Free Software Foundation, Inc.
+;; Copyright (C) 1993, 1994, 1995, 1997Free Software Foundation, Inc.
;; Contributed by Steve Chamberlain (sac@cygnus.com).
;; Improved by Jim Wilson (wilson@cygnus.com).
@@ -80,7 +80,7 @@
;; cbranch conditional branch instructions
;; jump unconditional jumps
;; arith ordinary arithmetic
-;; arith3 a compound insn that behaves similarily to a sequence of
+;; arith3 a compound insn that behaves similarly to a sequence of
;; three insns of type arith
;; arith3b like above, but might end with a redirected branch
;; load from memory
@@ -169,7 +169,7 @@
;; between the actual call address and the function arguments.
;; ADJUST_COST can only properly handle reductions of the cost, so we
;; use a latency of three here.
-;; We only do this for SImode loads of general regsiters, to make the work
+;; We only do this for SImode loads of general registers, to make the work
;; for ADJUST_COST easier.
(define_function_unit "memory" 1 0
(eq_attr "type" "load_si,pcload_si")
@@ -563,7 +563,7 @@
;; registers as a normal function call would.
;; The INSN_REFERENCES_ARE_DELAYED in sh.h is problematic because it
-;; also has an effect on the register that holds the addres of the sfunc.
+;; also has an effect on the register that holds the address of the sfunc.
;; To make this work, we have an extra dummy insns that shows the use
;; of this register for reorg.
@@ -2646,7 +2646,7 @@
return \"\";
}"
;; Need a variable length for this to be processed in each shorten_branch pass.
-;; The actual work is done in ADJUST_INSN_LENTH, because length attributes
+;; The actual work is done in ADJUST_INSN_LENGTH, because length attributes
;; need to be (a choice of) constants.
;; We use the calculated length before ADJUST_INSN_LENGTH to
;; determine if the insn_addresses array contents are valid.
@@ -2807,7 +2807,7 @@
"operands[2] = gen_reg_rtx (SImode);")
;; Recognize mov #-1/negc/neg sequence, and change it to movt/add #-1.
-;; This prevents a regression that occured when we switched from xor to
+;; This prevents a regression that occurred when we switched from xor to
;; mov/neg for sne.
(define_split
@@ -2923,7 +2923,7 @@
""
".align %O0"
;; Need a variable length for this to be processed in each shorten_branch pass.
-;; The actual work is done in ADJUST_INSN_LENTH, because length attributes
+;; The actual work is done in ADJUST_INSN_LENGTH, because length attributes
;; need to be (a choice of) constants.
[(set (attr "length")
(if_then_else (ne (pc) (pc)) (const_int 2) (const_int 0)))
@@ -3322,7 +3322,7 @@
}"
[(set_attr "length" "10")])
-;; Switch back to the original stack for interrupt funtions with the
+;; Switch back to the original stack for interrupt functions with the
;; sp_switch attribute. */
(define_insn "sp_switch_2"
[(const_int 2)]
diff --git a/gcc/config/sparc/rtems.h b/gcc/config/sparc/rtems.h
index 6a9d92a..55b7779 100644
--- a/gcc/config/sparc/rtems.h
+++ b/gcc/config/sparc/rtems.h
@@ -1,4 +1,4 @@
-/* Definitions for rtems targetting a SPARC using a.out.
+/* Definitions for rtems targeting a SPARC using a.out.
Copyright (C) 1996, 1997 Free Software Foundation, Inc.
Contributed by Joel Sherrill (joel@OARcorp.com).
diff --git a/gcc/config/sparc/sparc.c b/gcc/config/sparc/sparc.c
index a96bbf9..692ba41 100644
--- a/gcc/config/sparc/sparc.c
+++ b/gcc/config/sparc/sparc.c
@@ -3334,8 +3334,8 @@ output_function_prologue (file, size, leaf_function)
else if (! leaf_function && TARGET_BROKEN_SAVERESTORE)
{
/* We assume the environment will properly handle or otherwise avoid
- trouble associated with an interrupt occuring after the `save' or
- trap occuring during it. */
+ trouble associated with an interrupt occurring after the `save' or
+ trap occurring during it. */
fprintf (file, "\tsave\n");
if (actual_fsize <= 4096)
@@ -3830,7 +3830,7 @@ function_arg (cum, mode, type, named, incoming_p)
/* ??? This will cause the value to be passed in the fp reg and
in the stack. When a prototype exists we want to pass the
value in the reg but reserve space on the stack. That's an
- optimization, and is defered [for a bit]. */
+ optimization, and is deferred [for a bit]. */
if ((regno - SPARC_FP_ARG_FIRST) >= SPARC_INT_ARG_MAX * 2)
return gen_rtx (PARALLEL, mode,
gen_rtvec (2,
@@ -4246,7 +4246,8 @@ sparc_builtin_saveregs (arglist)
address, ptr_mode,
GEN_INT (UNITS_PER_WORD
* (NPARM_REGS (word_mode) - first_reg)),
- TYPE_MODE (sizetype), GEN_INT (MEMORY_USE_RW), QImode);
+ TYPE_MODE (sizetype), GEN_INT (MEMORY_USE_RW),
+ TYPE_MODE (integer_type_node));
return address;
}
diff --git a/gcc/config/sparc/sparc.h b/gcc/config/sparc/sparc.h
index 9d8f1a1..d839432 100644
--- a/gcc/config/sparc/sparc.h
+++ b/gcc/config/sparc/sparc.h
@@ -440,8 +440,8 @@ extern int target_flags;
/* Non-zero means the cpu has broken `save' and `restore' insns, only
the trivial versions work (save %g0,%g0,%g0; restore %g0,%g0,%g0).
We assume the environment will properly handle or otherwise avoid
- trouble associated with an interrupt occuring after the `save' or trap
- occuring during it. */
+ trouble associated with an interrupt occurring after the `save' or trap
+ occurring during it. */
#define MASK_BROKEN_SAVERESTORE 0x200000
#define TARGET_BROKEN_SAVERESTORE (target_flags & MASK_BROKEN_SAVERESTORE)
@@ -1131,7 +1131,7 @@ extern int sparc_mode_class[];
It is important that SPARC_ICC_REG have class NO_REGS. Otherwise combine
may try to use it to hold an SImode value. See register_operand.
- ??? Should %fcc[0123] be handled similarily?
+ ??? Should %fcc[0123] be handled similarly?
*/
enum reg_class { NO_REGS, FPCC_REGS, GENERAL_REGS, FP_REGS, EXTRA_FP_REGS,
diff --git a/gcc/config/sparc/xm-linux.h b/gcc/config/sparc/xm-linux.h
index 9299e31..f68f571 100644
--- a/gcc/config/sparc/xm-linux.h
+++ b/gcc/config/sparc/xm-linux.h
@@ -1,4 +1,4 @@
-/* Configuration for GCC for SPARC running Linux.
+/* Configuration for GCC for SPARC running Linux-based GNU systems.
Copyright (C) 1996, 1997 Free Software Foundation, Inc.
Contributed by Eddie C. Dost (ecd@skynet.be)
diff --git a/gcc/config/v850/lib1funcs.asm b/gcc/config/v850/lib1funcs.asm
index 3f6f226..100d901 100644
--- a/gcc/config/v850/lib1funcs.asm
+++ b/gcc/config/v850/lib1funcs.asm
@@ -1172,7 +1172,7 @@ __save_interrupt:
.size __save_interrupt,.-__save_interrupt
/* Restore saved registers, deallocate stack and return from the interrupt */
- /* Called via: jr __return_interupt */
+ /* Called via: jr __return_interrupt */
.align 2
.globl __return_interrupt
.type __return_interrupt,@function
diff --git a/gcc/config/v850/v850.c b/gcc/config/v850/v850.c
index 564e8ee..0962c77 100644
--- a/gcc/config/v850/v850.c
+++ b/gcc/config/v850/v850.c
@@ -448,7 +448,7 @@ print_operand (file, x, code)
break;
case 'S':
{
- /* if it's a referance to a TDA variable, use sst/sld vs. st/ld */
+ /* if it's a reference to a TDA variable, use sst/sld vs. st/ld */
if (GET_CODE (x) == MEM && ep_memory_operand (x, GET_MODE (x), FALSE))
fputs ("s", file);
@@ -2157,8 +2157,8 @@ pattern_is_ok_for_prologue (op, mode)
return 0;
/* If the register is being pushed somewhere other than the stack
- space just aquired by the first operand then abandon this quest.
- Note: the test is <= becuase both values are negative. */
+ space just acquired by the first operand then abandon this quest.
+ Note: the test is <= because both values are negative. */
if (INTVAL (XEXP (plus, 1))
<= INTVAL (XEXP (SET_SRC (XVECEXP (op, 0, 0)), 1)))
{
diff --git a/gcc/config/v850/v850.h b/gcc/config/v850/v850.h
index 6bbf6ce..9044f44 100644
--- a/gcc/config/v850/v850.h
+++ b/gcc/config/v850/v850.h
@@ -1,5 +1,4 @@
-/* Definitions of target machine for GNU compiler.
- NEC V850 series
+/* Definitions of target machine for GNU compiler. NEC V850 series
Copyright (C) 1996, 1997 Free Software Foundation, Inc.
Contributed by Jeff Law (law@cygnus.com).
@@ -83,7 +82,7 @@ extern int target_flags;
* Passing/returning of large structures probably isn't the same
as GHS. We don't have enough documentation on their conventions
- to be compatable.
+ to be compatible.
* Tests of SETUP_INCOMING_VARARGS need to be made runtime checks
since it depends on TARGET_GHS. */
@@ -348,7 +347,7 @@ extern struct small_memory_info small_memory[(int)SMALL_MEMORY_max];
On the 850, we make the return registers first, then all of the volatile
registers, then the saved registers in reverse order to better save the
- registers with an out of line function , and finnally the fixed
+ registers with an out of line function, and finally the fixed
registers. */
#define REG_ALLOC_ORDER \
@@ -1007,7 +1006,7 @@ do { \
switch on CODE.
There aren't DImode MOD, DIV or MULT operations, so call them
- very expensive. Everything else is pretty much a costant cost. */
+ very expensive. Everything else is pretty much a constant cost. */
#define RTX_COSTS(RTX,CODE,OUTER_CODE) \
case MOD: \
@@ -1296,7 +1295,7 @@ do { char dstr[30]; \
if ((LOG) != 0) \
fprintf (FILE, "\t.align %d\n", (LOG))
-/* We don't have to worry about dbx compatability for the v850. */
+/* We don't have to worry about dbx compatibility for the v850. */
#define DEFAULT_GDB_EXTENSIONS 1
/* Use stabs debugging info by default. */
diff --git a/gcc/config/v850/v850.md b/gcc/config/v850/v850.md
index c2095f2..0ba10ca 100644
--- a/gcc/config/v850/v850.md
+++ b/gcc/config/v850/v850.md
@@ -46,7 +46,7 @@
;; none_0hit - insn does not affect cc but it does modify operand 0
;; This attribute is used to keep track of when operand 0 changes.
;; See the description of NOTICE_UPDATE_CC for more info.
-;; set_znv - sets z,n,v to useable values; c is unknown.
+;; set_znv - sets z,n,v to usable values; c is unknown.
;; set_zn - sets z,n to usable values; v,c is unknown.
;; compare - compare instruction
;; clobber - value of cc is unknown
@@ -935,7 +935,7 @@
/* Shift index for the table array access. */
emit_insn (gen_ashlsi3 (reg, reg, GEN_INT (TARGET_BIG_SWITCH ? 2 : 1)));
- /* Load the table address into a psuedo. */
+ /* Load the table address into a pseudo. */
emit_insn (gen_movsi (tableaddress,
gen_rtx (LABEL_REF, VOIDmode, operands[3])));
/* Add the table address to the index. */
@@ -1201,8 +1201,8 @@
;; an interrupt function makes a call.
;; UNSPEC_VOLATILE is considered to use and clobber all hard registers and
;; all of memory. This blocks insns from being moved across this point.
-;; This is needed because the rest of the compiler is not reading to handle
-;; insns this compilcated
+;; This is needed because the rest of the compiler is not ready to handle
+;; insns this complicated.
(define_insn "save_all_interrupt"
[(unspec_volatile [(const_int 0)] 0)]
@@ -1249,8 +1249,8 @@
;; Restore all registers saved when an interrupt function makes a call.
;; UNSPEC_VOLATILE is considered to use and clobber all hard registers and
;; all of memory. This blocks insns from being moved across this point.
-;; This is needed because the rest of the compiler is not reading to handle
-;; insns this compilcated
+;; This is needed because the rest of the compiler is not ready to handle
+;; insns this complicated.
(define_insn "restore_all_interrupt"
[(unspec_volatile [(const_int 0)] 1)]
diff --git a/gcc/config/xm-linux.h b/gcc/config/xm-linux.h
index 4baa426..9a3838b 100644
--- a/gcc/config/xm-linux.h
+++ b/gcc/config/xm-linux.h
@@ -1,4 +1,4 @@
-/* Configuration for GCC for Intel i386 running Linux.
+/* Configuration for GCC for Intel i386 running Linux-based GNU systems.
Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
Contributed by H.J. Lu (hjl@nynexst.com)
@@ -19,15 +19,6 @@ along with GNU CC; see the file COPYING. If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA. */
-#undef HAVE_VPRINTF
-#define HAVE_VPRINTF
-
-#undef HAVE_POPEN
-#define HAVE_POPEN
-
-#undef HAVE_PUTENV
-#define HAVE_PUTENV
-
#undef HAVE_ATEXIT
#define HAVE_ATEXIT
@@ -40,8 +31,3 @@ Boston, MA 02111-1307, USA. */
#undef BSTRING
#define BSTRING
-#undef bcmp
-#undef bcopy
-#undef bzero
-#undef index
-#undef rindex
diff --git a/gcc/config/xm-svr4.h b/gcc/config/xm-svr4.h
index 49a751d..8534aaa 100644
--- a/gcc/config/xm-svr4.h
+++ b/gcc/config/xm-svr4.h
@@ -1,5 +1,5 @@
/* Configuration for GNU C-compiler for hosts running System V Release 4
- Copyright (C) 1988 Free Software Foundation, Inc.
+ Copyright (C) 1988, 1997 Free Software Foundation, Inc.
This file is part of GNU CC.
@@ -18,15 +18,7 @@ along with GNU CC; see the file COPYING. If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA. */
-#define bcopy(src,dst,len) memcpy ((dst),(src),(len))
-#define bzero(dst,len) memset ((dst),0,(len))
-#define bcmp(left,right,len) memcmp ((left),(right),(len))
-
-#define rindex strrchr
-#define index strchr
-
#define USG
-#define HAVE_VPRINTF
#define POSIX
diff --git a/gcc/config/alpha/elf.h b/gcc/config/alpha/elf.h
index 2279fb1..b1466ae 100644
--- a/gcc/config/alpha/elf.h
+++ b/gcc/config/alpha/elf.h
@@ -20,10 +20,10 @@ the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA. */
/* This is used on Alpha platforms that use the ELF format.
-Currently only Linux uses this. */
+ Currently only GNU/Linux uses this. */
#undef TARGET_VERSION
-#define TARGET_VERSION fprintf (stderr, " (Alpha Linux/ELF)");
+#define TARGET_VERSION fprintf (stderr, " (Alpha GNU/Linux with ELF)");
#undef OBJECT_FORMAT_COFF
#undef EXTENDED_COFF
@@ -489,8 +489,8 @@ do { \
#undef PREFERRED_DEBUGGING_TYPE
#define PREFERRED_DEBUGGING_TYPE DBX_DEBUG
-/* Provide a STARTFILE_SPEC appropriate for Linux. Here we add
- the Linux magical crtbegin.o file (see crtstuff.c) which
+/* Provide a STARTFILE_SPEC appropriate for GNU/Linux. Here we add
+ the GNU/Linux magical crtbegin.o file (see crtstuff.c) which
provides part of the support for getting C++ file-scope static
object constructed before entering `main'. */
@@ -500,11 +500,11 @@ do { \
%{pg:gcrt1.o%s} %{!pg:%{p:gcrt1.o%s} %{!p:crt1.o%s}}}\
crti.o%s crtbegin.o%s"
-/* Provide a ENDFILE_SPEC appropriate for Linux. Here we tack on
- the Linux magical crtend.o file (see crtstuff.c) which
+/* Provide a ENDFILE_SPEC appropriate for GNU/Linux. Here we tack on
+ the GNU/Linux magical crtend.o file (see crtstuff.c) which
provides part of the support for getting C++ file-scope static
object constructed before entering `main', followed by a normal
- Linux "finalizer" file, `crtn.o'. */
+ GNU/Linux "finalizer" file, `crtn.o'. */
#undef ENDFILE_SPEC
#define ENDFILE_SPEC \
diff --git a/gcc/config/linux.h b/gcc/config/linux.h
index ba81586..870bbd2 100644
--- a/gcc/config/linux.h
+++ b/gcc/config/linux.h
@@ -1,4 +1,4 @@
/* Definitions for Linux with ELF format
Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
Contributed by Eric Youngdale.
Modified for stabs-in-ELF by H.J. Lu.
@@ -26,7 +26,7 @@ Boston, MA 02111-1307, USA. */
#undef HAVE_ATEXIT
#define HAVE_ATEXIT
/* Linux uses ctype from glibc.a. I am not sure how complete it is.
For now, we play safe. It may change later. */
#if 0
@@ -59,8 +59,8 @@ Boston, MA 02111-1307, USA. */
fprintf (FILE, "\t.version\t\"01.01\"\n"); \
} while (0)
-/* Provide a STARTFILE_SPEC appropriate for Linux. Here we add
- the Linux magical crtbegin.o file (see crtstuff.c) which
+/* Provide a STARTFILE_SPEC appropriate for GNU/Linux. Here we add
+ the GNU/Linux magical crtbegin.o file (see crtstuff.c) which
provides part of the support for getting C++ file-scope static
object constructed before entering `main'. */
@@ -72,11 +72,11 @@ Boston, MA 02111-1307, USA. */
%{!profile:crt1.o%s}}}} \
crti.o%s %{!shared:crtbegin.o%s} %{shared:crtbeginS.o%s}"
-/* Provide a ENDFILE_SPEC appropriate for Linux. Here we tack on
- the Linux magical crtend.o file (see crtstuff.c) which
+/* Provide a ENDFILE_SPEC appropriate for GNU/Linux. Here we tack on
+ the GNU/Linux magical crtend.o file (see crtstuff.c) which
provides part of the support for getting C++ file-scope static
object constructed before entering `main', followed by a normal
- Linux "finalizer" file, `crtn.o'. */
+ GNU/Linux "finalizer" file, `crtn.o'. */
#undef ENDFILE_SPEC
#define ENDFILE_SPEC \
@@ -94,9 +94,8 @@ Boston, MA 02111-1307, USA. */
#undef LIB_SPEC
/* We no longer link with libc_p.a or libg.a by default. If you
- * want to profile or debug the Linux C library, please add
- * -profile or -ggdb to LDFLAGS at the link time, respectively.
- */
+ want to profile or debug the GNU/Linux C library, please add
+ -profile or -ggdb to LDFLAGS at the link time, respectively. */
#if 1
#ifdef USE_GNULIBC_1
#define LIB_SPEC \
@@ -1,4 +1,4 @@
-/* Definitions for Linux with ELF format
+/* Definitions for Linux-based GNU systems with ELF format
Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
Contributed by Eric Youngdale.
@@ -26,7 +26,7 @@ Boston, MA 02111-1307, USA. */
#undef HAVE_ATEXIT
#define HAVE_ATEXIT
-/* Linux uses ctype from glibc.a. I am not sure how complete it is.
+/* GNU/Linux uses ctype from glibc.a. I am not sure how complete it is.
For now, we play safe. It may change later. */
#if 0
diff --git a/gcc/config/rs6000/rs6000.c b/gcc/config/rs6000/rs6000.c
index 464252d..2dbdb92 100644
--- a/gcc/config/rs6000/rs6000.c
+++ b/gcc/config/rs6000/rs6000.c
@@ -19,9 +19,9 @@ along with GNU CC; see the file COPYING. If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA. */
-#include "config.h"
#include <stdio.h>
#include <ctype.h>
+#include "config.h"
#include "rtl.h"
#include "regs.h"
#include "hard-reg-set.h"
@@ -2140,7 +2140,7 @@ rs6000_got_register (value)
}
/* Replace all occurances of register FROM with an new pseduo register in an insn X.
Store the pseudo register used in REG.
This is only safe during FINALIZE_PIC, since the registers haven't been setup
yet. */
@@ -2215,7 +2215,7 @@ void
rs6000_finalize_pic ()
{
/* Loop through all of the insns, replacing the special GOT_TOC_REGNUM
- with an appropriate pseduo register. If we find we need GOT/TOC,
+ with an appropriate pseudo register. If we find we need GOT/TOC,
add the appropriate init code. */
if (flag_pic && (DEFAULT_ABI == ABI_V4 || DEFAULT_ABI == ABI_SOLARIS))
{
@@ -2257,7 +2257,7 @@ rs6000_finalize_pic ()
}
-/* Search for any occurrance of the GOT_TOC register marker that should
+/* Search for any occurrence of the GOT_TOC register marker that should
have been eliminated, but may have crept back in. */
void
@@ -2140,7 +2140,7 @@ rs6000_got_register (value)
}
-/* Replace all occurances of register FROM with an new pseduo register in an insn X.
+/* Replace all occurrences of register FROM with an new pseudo register in an insn X.
Store the pseudo register used in REG.
This is only safe during FINALIZE_PIC, since the registers haven't been setup
diff --git a/gcc/config/sparc/linux-aout.h b/gcc/config/sparc/linux-aout.h
index df93361..7075b5f 100644
--- a/gcc/config/sparc/linux-aout.h
+++ b/gcc/config/sparc/linux-aout.h
@@ -1,4 +1,4 @@
/* Definitions for SPARC running Linux with a.out
Copyright (C) 1996, 1997 Free Software Foundation, Inc.
Contributed by Eddie C. Dost (ecd@skynet.be)
@@ -28,7 +28,7 @@ Boston, MA 02111-1307, USA. */
#undef HAVE_ATEXIT
#define HAVE_ATEXIT
/* Linux uses ctype from glibc.a. I am not sure how complete it is.
For now, we play safe. It may change later. */
#if 0
@@ -55,7 +55,7 @@ Boston, MA 02111-1307, USA. */
#define STARTFILE_SPEC "%{pg:gcrt0.o%s} %{!pg:%{p:gcrt0.o%s} %{!p:crt0.o%s}} %{static:-static}"
#undef TARGET_VERSION
-#define TARGET_VERSION fprintf (stderr, " (sparc Linux/a.out)");
+#define TARGET_VERSION fprintf (stderr, " (sparc GNU/Linux with a.out)");
#undef SIZE_TYPE
#define SIZE_TYPE "unsigned int"
@@ -84,9 +84,8 @@ Boston, MA 02111-1307, USA. */
#if 1
/* We no longer link with libc_p.a or libg.a by default. If you
- * want to profile or debug the Linux C library, please add
- * -lc_p or -ggdb to LDFLAGS at the link time, respectively.
- */
+ want to profile or debug the GNU/Linux C library, please add
+ -lc_p or -ggdb to LDFLAGS at the link time, respectively. */
#define LIB_SPEC \
"%{mieee-fp:-lieee} %{p:-lgmon} %{pg:-lgmon} %{!ggdb:-lc} %{ggdb:-lg}"
#else
@@ -106,7 +105,7 @@ Boston, MA 02111-1307, USA. */
#if 0
/* Define for support of TFmode long double and REAL_ARITHMETIC.
- Sparc ABI says that long double is 4 words. Linux does not support
+ Sparc ABI says that long double is 4 words. GNU/Linux does not support
long double yet. */
#define LONG_DOUBLE_TYPE_SIZE 128
#endif
@@ -1,4 +1,4 @@
-/* Definitions for SPARC running Linux with a.out
+/* Definitions for SPARC running Linux-based GNU systems with a.out.
Copyright (C) 1996, 1997 Free Software Foundation, Inc.
Contributed by Eddie C. Dost (ecd@skynet.be)
@@ -28,7 +28,7 @@ Boston, MA 02111-1307, USA. */
#undef HAVE_ATEXIT
#define HAVE_ATEXIT
-/* Linux uses ctype from glibc.a. I am not sure how complete it is.
+/* GNU/Linux uses ctype from glibc.a. I am not sure how complete it is.
For now, we play safe. It may change later. */
#if 0
diff --git a/gcc/config/sparc/linux.h b/gcc/config/sparc/linux.h
index 6f7a6ca..a312967 100644
--- a/gcc/config/sparc/linux.h
+++ b/gcc/config/sparc/linux.h
@@ -1,4 +1,4 @@
/* Definitions for SPARC running Linux with ELF
Copyright (C) 1996, 1997 Free Software Foundation, Inc.
Contributed by Eddie C. Dost (ecd@skynet.be)
@@ -27,7 +27,7 @@ Boston, MA 02111-1307, USA. */
#undef HAVE_ATEXIT
#define HAVE_ATEXIT
/* Linux uses ctype from glibc.a. I am not sure how complete it is.
For now, we play safe. It may change later. */
#if 0
@@ -57,8 +57,8 @@ Boston, MA 02111-1307, USA. */
fprintf (FILE, "\t.version\t\"01.01\"\n"); \
} while (0)
-/* Provide a STARTFILE_SPEC appropriate for Linux. Here we add
- the Linux magical crtbegin.o file (see crtstuff.c) which
+/* Provide a STARTFILE_SPEC appropriate for GNU/Linux. Here we add
+ the GNU/Linux magical crtbegin.o file (see crtstuff.c) which
provides part of the support for getting C++ file-scope static
object constructed before entering `main'. */
@@ -68,11 +68,11 @@ Boston, MA 02111-1307, USA. */
%{pg:gcrt1.o%s} %{!pg:%{p:gcrt1.o%s} %{!p:crt1.o%s}}}\
crti.o%s %{!shared:crtbegin.o%s} %{shared:crtbeginS.o%s}"
-/* Provide a ENDFILE_SPEC appropriate for Linux. Here we tack on
- the Linux magical crtend.o file (see crtstuff.c) which
+/* Provide a ENDFILE_SPEC appropriate for GNU/Linux. Here we tack on
+ the GNU/Linux magical crtend.o file (see crtstuff.c) which
provides part of the support for getting C++ file-scope static
object constructed before entering `main', followed by a normal
- Linux "finalizer" file, `crtn.o'. */
+ GNU/Linux "finalizer" file, `crtn.o'. */
#undef ENDFILE_SPEC
#define ENDFILE_SPEC \
@@ -88,7 +88,7 @@ Boston, MA 02111-1307, USA. */
"
#undef TARGET_VERSION
-#define TARGET_VERSION fprintf (stderr, " (sparc Linux/ELF)");
+#define TARGET_VERSION fprintf (stderr, " (sparc GNU/Linux with ELF)");
#undef SIZE_TYPE
#define SIZE_TYPE "unsigned int"
@@ -116,9 +116,8 @@ Boston, MA 02111-1307, USA. */
#undef LIB_SPEC
/* We no longer link with libc_p.a or libg.a by default. If you
- * want to profile or debug the Linux C library, please add
- * -lc_p or -ggdb to LDFLAGS at the link time, respectively.
- */
+ want to profile or debug the GNU/Linux C library, please add
+ -lc_p or -ggdb to LDFLAGS at the link time, respectively. */
#if 1
#ifdef USE_GNULIBC_1
#define LIB_SPEC \
@@ -136,7 +135,7 @@ Boston, MA 02111-1307, USA. */
%{!p:%{!pg:%{!g*:-lc} %{g*:-lg}}}}"
#endif
/* Provide a LINK_SPEC appropriate for Linux. Here we provide support
for the special GCC options -static and -shared, which allow us to
link things in one of these three modes by applying the appropriate
combinations of options at link-time. We like to support here for
@@ -234,7 +233,7 @@ do { \
#if 0
/* Define for support of TFmode long double and REAL_ARITHMETIC.
- Sparc ABI says that long double is 4 words. Linux does not support
+ Sparc ABI says that long double is 4 words. GNU/Linux does not support
long double yet. */
#define LONG_DOUBLE_TYPE_SIZE 128
#endif
@@ -1,4 +1,4 @@
-/* Definitions for SPARC running Linux with ELF
+/* Definitions for SPARC running Linux-based GNU systems with ELF.
Copyright (C) 1996, 1997 Free Software Foundation, Inc.
Contributed by Eddie C. Dost (ecd@skynet.be)
@@ -27,7 +27,7 @@ Boston, MA 02111-1307, USA. */
#undef HAVE_ATEXIT
#define HAVE_ATEXIT
-/* Linux uses ctype from glibc.a. I am not sure how complete it is.
+/* GNU/Linux uses ctype from glibc.a. I am not sure how complete it is.
For now, we play safe. It may change later. */
#if 0
@@ -136,7 +135,7 @@ Boston, MA 02111-1307, USA. */
%{!p:%{!pg:%{!g*:-lc} %{g*:-lg}}}}"
#endif
-/* Provide a LINK_SPEC appropriate for Linux. Here we provide support
+/* Provide a LINK_SPEC appropriate for GNU/Linux. Here we provide support
for the special GCC options -static and -shared, which allow us to
link things in one of these three modes by applying the appropriate
diff --git a/gcc/config/sparc/linux64.h b/gcc/config/sparc/linux64.h
index 56c2183..74f632b 100644
--- a/gcc/config/sparc/linux64.h
+++ b/gcc/config/sparc/linux64.h
@@ -1,4 +1,4 @@
/* Definitions for 64-bit SPARC running Linux with ELF
Copyright 1996, 1997 Free Software Foundation, Inc.
Contributed by David S. Miller (davem@caip.rutgers.edu)
@@ -52,8 +52,8 @@ Boston, MA 02111-1307, USA. */
#define LIBGCC_SPEC \
"%{!shared:-lgcc}"
-/* Provide a STARTFILE_SPEC appropriate for Linux. Here we add
- the Linux magical crtbegin.o file (see crtstuff.c) which
+/* Provide a STARTFILE_SPEC appropriate for GNU/Linux. Here we add
+ the GNU/Linux magical crtbegin.o file (see crtstuff.c) which
provides part of the support for getting C++ file-scope static
object constructed before entering `main'. */
@@ -63,18 +63,18 @@ Boston, MA 02111-1307, USA. */
%{pg:gcrt1.o%s} %{!pg:%{p:gcrt1.o%s} %{!p:crt1.o%s}}}\
crti.o%s %{!shared:crtbegin.o%s} %{shared:crtbeginS.o%s}"
-/* Provide a ENDFILE_SPEC appropriate for Linux. Here we tack on
- the Linux magical crtend.o file (see crtstuff.c) which
+/* Provide a ENDFILE_SPEC appropriate for GNU/Linux. Here we tack on
+ the GNU/Linux magical crtend.o file (see crtstuff.c) which
provides part of the support for getting C++ file-scope static
object constructed before entering `main', followed by a normal
- Linux "finalizer" file, `crtn.o'. */
+ GNU/Linux "finalizer" file, `crtn.o'. */
#undef ENDFILE_SPEC
#define ENDFILE_SPEC \
"%{!shared:crtend.o%s} %{shared:crtendS.o%s} crtn.o%s"
#undef TARGET_VERSION
-#define TARGET_VERSION fprintf (stderr, " (sparc64 Linux/ELF)");
+#define TARGET_VERSION fprintf (stderr, " (sparc64 GNU/Linux with ELF)");
/* A 64 bit v9 compiler with stack-bias,
in a Medium/Anywhere code model environment. */
@@ -113,15 +113,14 @@ Boston, MA 02111-1307, USA. */
%{posix:-D_POSIX_SOURCE} \
"
/* We no longer link with libc_p.a or libg.a by default. If you
- * want to profile or debug the Linux C library, please add
- * -lc_p or -ggdb to LDFLAGS at the link time, respectively.
- */
+ want to profile or debug the GNU/Linux C library, please add
+ -lc_p or -ggdb to LDFLAGS at the link time, respectively. */
#undef LIB_SPEC
#define LIB_SPEC \
"%{!shared: %{mieee-fp:-lieee} %{p:-lgmon} %{pg:-lgmon} \
%{!ggdb:-lc} %{ggdb:-lg}}"
/* Provide a LINK_SPEC appropriate for Linux. Here we provide support
for the special GCC options -static and -shared, which allow us to
link things in one of these three modes by applying the appropriate
combinations of options at link-time. We like to support here for
@@ -1,4 +1,4 @@
-/* Definitions for 64-bit SPARC running Linux with ELF
+/* Definitions for 64-bit SPARC running Linux-based GNU systems with ELF.
Copyright 1996, 1997 Free Software Foundation, Inc.
Contributed by David S. Miller (davem@caip.rutgers.edu)
@@ -113,15 +113,14 @@ Boston, MA 02111-1307, USA. */
"%{!shared: %{mieee-fp:-lieee} %{p:-lgmon} %{pg:-lgmon} \
%{!ggdb:-lc} %{ggdb:-lg}}"
-/* Provide a LINK_SPEC appropriate for Linux. Here we provide support
+/* Provide a LINK_SPEC appropriate for GNU/Linux. Here we provide support
for the special GCC options -static and -shared, which allow us to
link things in one of these three modes by applying the appropriate